@@ -142,7 +142,7 @@ class ExecutionProps:
     ) -> None:
         '''Properties for defining a ``ALIYUN::OOS::Execution``.
 
-        :param template_name: Property templateName: Template name. Content is limited to letters, numbers, underlined, underline, the length of 200 characters, and can not begin to ALIYUN, ACS, ALIBABA.
+        :param template_name: Property templateName: Template name. Content is limited to letters, numbers, underlined, underline, the length of 200 characters.
         :param mode: Property mode: Execution mode.
         :param parameters: Property parameters: Parameters for the execution of template.
         :param parent_execution_id: Property parentExecutionId: Parent execution ID.
@@ -176,7 +176,7 @@ class ExecutionProps:
     def template_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''Property templateName: Template name.
 
-        Content is limited to letters, numbers, underlined, underline, the length of 200 characters, and can not begin to ALIYUN, ACS, ALIBABA.
+        Content is limited to letters, numbers, underlined, underline, the length of 200 characters.
         '''
         result = self._values.get("template_name")
         assert result is not None, "Required property 'template_name' is missing"
@@ -560,7 +560,7 @@ class RosExecution(
     @jsii.member(jsii_name="templateName")
     def template_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
-        :Property: templateName: Template name. Content is limited to letters, numbers, underlined, underline, the length of 200 characters, and can not begin to ALIYUN, ACS, ALIBABA.
+        :Property: templateName: Template name. Content is limited to letters, numbers, underlined, underline, the length of 200 characters.
         '''
         return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], jsii.get(self, "templateName"))
 
@@ -872,7 +872,7 @@ class RosExecutionProps:
     @builtins.property
     def template_name(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
         '''
-        :Property: templateName: Template name. Content is limited to letters, numbers, underlined, underline, the length of 200 characters, and can not begin to ALIYUN, ACS, ALIBABA.
+        :Property: templateName: Template name. Content is limited to letters, numbers, underlined, underline, the length of 200 characters.
         '''
         result = self._values.get("template_name")
         assert result is not None, "Required property 'template_name' is missing"
